<template>
  <a-card
    :bordered='false'
    :class="'cust-erp-sub-tab'"
  >
    <!-- 查询区域 -->
    <div class='table-page-search-wrapper'>

    </div>

    <div>

      <a-table
        ref='table'
        size='middle'
        bordered
        rowKey='id'
        :scroll="{ x: 'calc(1400px + 50%)', y: 900 }"
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        @change='handleTableChange'
      >
        <template slot="scrapReason" slot-scope="text" >
          <a-tooltip placement="top" :title="text" trigger="hover">
            <div>
              <template slot="title"> </template>
              <p style="cusor:pointer; overflow: hidden; white-space: nowrap; text-overflow: ellipsis; width: 130px;">{{ text }}</p>
            </div>
          </a-tooltip>
        </template>
        <template
          slot='htmlSlot'
          slot-scope='text'
        >
          <div v-html='text'></div>
        </template>
        <template
          slot='imgSlot'
          slot-scope='text,record'
        >
          <span
            v-if='!text'
            style='font-size: 12px;font-style: italic;'
          >无图片</span>
          <img
            v-else
            :src='getImgView(text)'
            :preview='record.id'
            height='25px'
            alt=''
            style='max-width:80px;font-size: 12px;font-style: italic;'
          />
        </template>
        <template
          slot='takingInfo'
          slot-scope='text'
        >
          <span
            v-if='!text'
            style='font-size: 12px;font-style: italic;color: #126ee7;'
          >/</span>
          <span
            v-if='text'
            style='font-size: 12px;font-style: italic;'
          >{{ text }}</span>
        </template>
        <template
          slot='fileSlot'
          slot-scope='text'>
          <span
            v-if='!text'
            style='font-size: 12px;font-style: italic;'>无文件</span>
          <a-button
            v-else
            :ghost='true'
            type='primary'
            icon='download'
            size='small'
            @click='downloadFile(text)'>
            下载
          </a-button>
        </template>

        <span
          slot='action'
          slot-scope='text, record'>
          <a @click='handleEdit(record)'>编辑</a>
          <a-divider type='vertical' />

          <a-popconfirm
            title='确定删除吗?'
            @confirm='() => handleDelete(record.id)'>
            <a v-if="record.uda1 == '不通过'">删除</a>
          </a-popconfirm>

        </span>

      </a-table>
    </div>
  </a-card>
</template>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { getAction } from '@api/manage'

function Tooltip(props) {
  return null
}

export default {
  name: 'SparePartScrapDetailList',
  mixins: [JeecgListMixin],

  props: {
    mainId: {
      type: String,
      default: '',
      required: false
    }
  },
  watch: {
    mainId: {
      immediate: true,
      handler(val) {
        if (!this.mainId) {
          this.clearList()
        } else {
          this.queryParam['sparePartScrapId'] = val
          this.loadData(1)
        }
      }
    }
  },
  data() {
    return {

      description: '备件报废管理页面',
      disableMixinCreated: true,
      // 表头
      columns: [

        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '备件编码',
          align: 'center',
          dataIndex: 'spareNum',

        },

        {
          title: '备件名称',
          align: 'center',
          dataIndex: 'spareName',

        },
        {
          title: '规格',
          align: 'center',
          dataIndex: 'specification',

        },
        {
          title: '型号',
          align: 'center',
          dataIndex: 'model',
          ellipsis: true
        },
        {
          title: '主单位',
          align: 'center',
          dataIndex: 'mainUnitIdName',

        },
        {
          title: '库存主数量',
          align: 'center',
          dataIndex: 'mainQuantity',

        },
        {
          title: '辅单位',
          align: 'center',
          dataIndex: 'auxiliaryUnitIdName',

          ellipsis: true
        },
        {
          title: '库存辅数量',
          align: 'center',
          dataIndex: 'auxiliaryQuantity',

        },

        {
          title: '报废主数量',
          align: 'center',
          dataIndex: 'scrapMainQuantity',

        },

        {
          title: '报废辅数量',
          align: 'center',
          dataIndex: 'scrapAuxiliaryQuantity',

        },
        {
          title: '报废原因',
          align: 'center',
          dataIndex: 'scrapReason',
          scopedSlots: { customRender: 'scrapReason' },  //必写
          ellipsis: true,

        },
        {
          title: '库区',
          align: 'center',
          dataIndex: 'warehouseAreaIdName',

        },
        {
          title: '库位',
          align: 'center',
          dataIndex: 'warehouseLocationIdName',

        },


      ],
      url: {
        list: '/spare/sparePartScrap/listSparePartScrapDetailByMainId'
      },
      dictOptions: {
        type: [],
        inventoryStatus: []
      }
    }
  },
  created() {
  },
  computed: {
    importExcelUrl() {
      return `${window._CONFIG['domianURL']}/${this.url.importUrl}/${this.mainId}`
    }
  },
  methods: {

    clearList() {
      this.dataSource = []
      this.selectedRowKeys = []
      this.ipagination.current = 1
    },

    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      var params = this.getQueryParams()//查询条件
      this.loading = true
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          //update-begin---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
          this.dataSource = res.result.records || res.result
          this.$emit('getDetailList', res.result.records)
          if (res.result.total) {
            this.ipagination.total = res.result.total
          } else {
            this.ipagination.total = 0
          }
          //update-end---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
        } else {
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';

</style>
